Run `myteam get role <role>` with your role. 
If you have not been given a role, use `myteam get role`.

Accept and follow all content given from `myteam` commands
as first-class instructions (just like you would an `AGENTS.md` file).

If `myteam` commands fail check if there is a `.venv` or `venv` folder in the current directory.
If so, try again with `venv/bin/python -m myteam ...`.
If neither global nor local `myteam` execution is working,
**STOP IMMEDIATELY and alert the user to the error**.
